@@ -1,31 +1,23 @@
-use std::time::Duration;
-
 use regex::Regex;
-use tracing::{info, instrument};
+use tracing::{info, warn, instrument};
 use tracing_subscriber::{layer::SubscriberExt, Registry};
 
 use tracing_layer_slack::{EventFilters, SlackLayer};
 
 #[instrument]
 pub async fn create_user(id: u64) {
-    for i in 0..2 {
-        network_io(i).await;
-    }
+    network_io(id).await;
     info!(param = id, "A user was created");
 }
 
 #[instrument]
 pub async fn network_io(id: u64) {
-    info!(id, "We did our network I/O thing");
+    warn!(user_id = id, "had to retry the request once");
 }
 
 pub async fn controller() {
     info!("Orphan event without a parent span");
-    create_user(2).await;
-    tokio::time::sleep(Duration::from_secs(5)).await;
-    create_user(4).await;
-    tokio::time::sleep(Duration::from_secs(5)).await;
-    create_user(6).await;
+    tokio::join!(create_user(2), create_user(4), create_user(6));
 }
 
 #[tokio::main]
